@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemBasicPlugin.cpp 3928 2007-01-22 14:59:07Z chpe $
+ * $Id: totemBasicPlugin.cpp 5065 2008-02-04 14:32:50Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -49,12 +49,21 @@ static const char kClassDescription[] = "totemBasicPlugin";
 static const char kPluginDescription[] = "Totem Web Browser Plugin " VERSION;
 
 static const totemPluginMimeEntry kMimeTypes[] = {
-	{ "application/ogg", "ogg", NULL, FALSE },
-	{ "video/mpeg", "mpg, mpeg, mpe", NULL, FALSE },
-	{ "audio/wav", "wav", NULL, FALSE },
-	{ "audio/x-wav", "wav", NULL, TRUE },
-	{ "audio/mpeg", "mp3", NULL, FALSE },
-	{ "audio/x-mpeg", "mp3", NULL, TRUE }
+	{ "application/x-ogg","ogg",NULL },
+	{ "application/ogg", "ogg", NULL },
+	{ "audio/ogg", "oga", NULL },
+	{ "audio/x-ogg", "ogg", NULL },
+	{ "video/ogg", "ogv", NULL },
+	{ "video/x-ogg", "ogg", NULL },
+	{ "application/annodex", "anx", NULL },
+	{ "audio/annodex", "axa", NULL },
+	{ "video/annodex", "axv", NULL },
+	{ "video/mpeg", "mpg, mpeg, mpe", NULL },
+	{ "audio/wav", "wav", NULL },
+	{ "audio/x-wav", "wav", NULL },
+	{ "audio/mpeg", "mp3", NULL },
+	{ "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
+	{ "video/flv", "flv", "application/x-flash-video" },
 };
 
 totemScriptablePlugin::totemScriptablePlugin (totemPlugin *aPlugin)
@@ -74,6 +83,12 @@ totemScriptablePlugin::PluginDescription ()
   return (char*) kPluginDescription;
 }
 
+/* static */ char *
+totemScriptablePlugin::PluginLongDescription ()
+{
+  return (char*) totem_plugin_get_long_description();
+}
+
 /* static */ void
 totemScriptablePlugin::PluginMimeTypes (const totemPluginMimeEntry **_entries,
 					PRUint32 *_count)
