@@ -244,7 +244,65 @@ totemPlugin::SetVolume (gdouble aVolume)
 				    G_TYPE_INVALID);
 
 	return NS_OK;
+}
 
+nsresult
+totemPlugin::SetFullscreen (gboolean enabled)
+{
+	D ("SetFullscreen '%d'", enabled);
+
+	/* FIXME: queue the action instead */
+	if (!mViewerReady)
+		return NS_OK;
+
+	NS_ASSERTION (mViewerProxy, "No viewer proxy");
+	dbus_g_proxy_call_no_reply (mViewerProxy,
+				    "SetFullscreen",
+				    G_TYPE_BOOLEAN, enabled,
+				    G_TYPE_INVALID,
+				    G_TYPE_INVALID);
+
+	return NS_OK;
+}
+
+nsresult
+totemPlugin::ClearPlaylist (void)
+{
+	D ("ClearPlaylist");
+
+	/* FIXME: queue the action instead */
+	if (!mViewerReady)
+		return NS_OK;
+
+	NS_ASSERTION (mViewerProxy, "No viewer proxy");
+	dbus_g_proxy_call_no_reply (mViewerProxy,
+				    "ClearPlaylist",
+				    G_TYPE_INVALID,
+				    G_TYPE_INVALID);
+
+	return NS_OK;
+}
+
+nsresult
+totemPlugin::AddItem (const nsACString &aURI)
+{
+	const nsCString string (aURI);
+	const char *str = string.get ();
+
+	D ("AddItem '%s'", str);
+
+	/* FIXME: queue the action instead */
+	if (!mViewerReady)
+		return NS_OK;
+
+	NS_ASSERTION (mViewerProxy, "No viewer proxy");
+	dbus_g_proxy_call_no_reply (mViewerProxy,
+				    "AddItem",
+				    G_TYPE_STRING, str,
+				    G_TYPE_INVALID,
+				    G_TYPE_INVALID);
+
+	return NS_OK;
 }
 
 /* Viewer interaction */
@@ -472,6 +530,20 @@ totemPlugin::ViewerSetup ()
 				     reinterpret_cast<void*>(this),
 				     NULL);
 
+	dbus_g_object_register_marshaller
+		(totempluginviewer_marshal_VOID__STRING_BOXED,
+		 G_TYPE_NONE, G_TYPE_STRING, G_TYPE_BOXED, G_TYPE_INVALID);
+	dbus_g_proxy_add_signal (mViewerProxy,
+				 "PropertyChange",
+				 G_TYPE_STRING,
+				 G_TYPE_VALUE,
+				 G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (mViewerProxy,
+				     "PropertyChange",
+				     G_CALLBACK (PropertyChangeCallback),
+				     reinterpret_cast<void*>(this),
+				     NULL);
+
 	if (mHidden) {
 		ViewerReady ();
 	} else {
@@ -517,6 +589,10 @@ totemPlugin::ViewerCleanup ()
 						"Tick",
 						G_CALLBACK (TickCallback),
 						reinterpret_cast<void*>(this));
+		dbus_g_proxy_disconnect_signal (mViewerProxy,
+						"PropertyChange",
+						G_CALLBACK (PropertyChangeCallback),
+						reinterpret_cast<void*>(this));
 
 		g_object_unref (mViewerProxy);
 		mViewerProxy = NULL;
@@ -757,7 +833,7 @@ totemPlugin::RequestStream (PRBool aForceViewer)
 		requestURI = mURLURI;
 		baseURI = mSrcURI; /* FIXME: that correct? */
 	}
-#endif
+#endif /* TOTEM_GMP_PLUGIN */
 
 #ifdef TOTEM_NARROWSPACE_PLUGIN
 	/* Prefer qtsrc over src */
@@ -771,7 +847,11 @@ totemPlugin::RequestStream (PRBool aForceViewer)
 		requestURL = href;
 	}
 #endif
-#endif
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
+
+#ifdef TOTEM_MULLY_PLUGIN
+	aForceViewer = PR_TRUE;
+#endif /* TOTEM_MULLY_PLUGIN */
 
 	/* Fallback */
 	if (!requestURI)
@@ -942,6 +1022,25 @@ totemPlugin::TickCallback (DBusGProxy *proxy,
 	plugin->mDuration = aDuration;
 }
 
+/* static */ void PR_CALLBACK
+totemPlugin::PropertyChangeCallback (DBusGProxy  *proxy,
+				     const char *aType,
+				     GValue *value,
+				     void *aData)
+{
+	totemPlugin *plugin = reinterpret_cast<totemPlugin*>(aData);
+
+	NS_ASSERTION (aType != NULL, "aType is NULL probably garbage");
+
+	DD ("PropertyChange signal received, aType %s", aType);
+
+	if (strcmp (aType, TOTEM_PROPERTY_VOLUME) == 0) {
+		plugin->mVolume = g_value_get_double (value);
+	} else if (strcmp (aType, TOTEM_PROPERTY_ISFULLSCREEN) == 0) {
+		plugin->mIsFullscreen = g_value_get_boolean (value);
+	}
+}
+
 /* static */ void PR_CALLBACK
 totemPlugin::ViewerSetWindowCallback (DBusGProxy *aProxy,
 				      DBusGProxyCall *aCall,
@@ -1115,9 +1214,9 @@ totemPlugin::ParseBoolean (const char *key,
 {
 	if (value == NULL || strcmp (value, "") == 0)
 		return default_val;
-	if (g_ascii_strcasecmp (value, "false") == 0)
+	if (g_ascii_strcasecmp (value, "false") == 0 || g_ascii_strcasecmp (value, "no") == 0)
 		return PR_FALSE;
-	if (g_ascii_strcasecmp (value, "true") == 0)
+	if (g_ascii_strcasecmp (value, "true") == 0 || g_ascii_strcasecmp (value, "yes") == 0)
 		return PR_TRUE;
 
         char *endptr = NULL;
@@ -1726,10 +1825,13 @@ totemPlugin::Init (NPMIMEType mimetype,
 	mHidden = g_hash_table_lookup (args, "hidden") != NULL &&
 		  GetBooleanValue (args, "hidden", PR_TRUE);
 
-	/* Most for RealAudio streams, but also used as a replacement for
-	 * HIDDEN=TRUE attribute.
+	/* Used as a replacement for HIDDEN=TRUE attribute.
+	 * See http://mxr.mozilla.org/mozilla/source/modules/plugin/base/src/ns4xPluginInstance.cpp#1135
+	 * We don't use:
+	 * width <= 0 || height <= 0
+	 * as -1 is our value for unset/unknown sizes
 	 */
-	if (width == 0 && height == 0)
+	if (width == 0 || height == 0)
 		mHidden = PR_TRUE;
 
 	/* Whether to automatically stream and play the content */
@@ -1788,12 +1890,26 @@ totemPlugin::Init (NPMIMEType mimetype,
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
 
 /* FIXME */
+#ifdef TOTEM_MULLY_PLUGIN
+	value = (const char *) g_hash_table_lookup (args, "video");
+	if (value) {
+		SetSrc (nsDependentCString (value));
+	}
+#endif /* TOTEM_MULLY_PLUGIN */
+
+#ifdef TOTEM_CONE_PLUGIN
+	value = (const char *) g_hash_table_lookup (args, "target");
+	if (value) {
+		SetSrc (nsDependentCString (value));
+	}
+#endif /* TOTEM_CONE_PLUGIN */
+
 #if 0 //def TOTEM_MULLY_PLUGIN
 	/* Click to play behaviour of the DivX plugin */
 	char *previewimage = (const char *) g_hash_table_lookup (args, "previewimage");
 	if (value != NULL)
 		mHref = g_strdup (mSrc);
-#endif /* TOTEM_NARROWSPACE_PLUGIN */
+#endif /* TOTEM_MULLY_PLUGIN */
 
 	/* If we're set to start automatically, we'll use the src stream */
 	if (mRequestURI &&
@@ -2138,6 +2254,8 @@ totemPlugin::Write (NPStream *stream,
 						    G_TYPE_INVALID);
 
 			return len;
+		} else {
+			D ("Is not playlist: totem_pl_parser_can_parse_from_data failed (len %d)", len);
 		}
 	}
 
