@@ -26,6 +26,7 @@
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-mime-info.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <dlfcn.h>
 
 #include "npapi.h"
 #include "npupp.h"
@@ -202,8 +203,8 @@ totem_plugin_print (NPP instance,
 	D ("Print");
 }
 
-static char *
-totem_plugin_get_description (void)
+const char *
+totem_plugin_get_long_description (void)
 {
 	return "The <a href=\"http://www.gnome.org/projects/totem/\">Totem</a> " PACKAGE_VERSION " plugin handles video and audio streams.";
 }
@@ -228,16 +229,16 @@ totem_plugin_get_value (NPP instance,
 		*((char **)value) = totemScriptablePlugin::PluginDescription ();
 		break;
 	case NPPVpluginDescriptionString:
-		*((char **)value) = totem_plugin_get_description();
+		*((char **)value) = totemScriptablePlugin::PluginLongDescription ();
 		break;
 	case NPPVpluginNeedsXEmbed:
 		*((NPBool *)value) = TRUE;
 		break;
 	case NPPVpluginScriptableIID: {
-		nsIID* ptr = NS_STATIC_CAST (nsIID *, totemPlugin::sNPN.memalloc (sizeof (nsIID)));
+		nsIID* ptr = static_cast<nsIID *>(totemPlugin::sNPN.memalloc (sizeof (nsIID)));
 		if (ptr) {
 			*ptr = NS_GET_IID (nsISupports);
-			*NS_STATIC_CAST (nsIID **, value) = ptr;
+			*static_cast<nsIID **>(value) = ptr;
 		} else {
 			err = NPERR_OUT_OF_MEMORY_ERROR;
 		}
@@ -252,6 +253,18 @@ totem_plugin_get_value (NPP instance,
 		}
 		break;
 	}
+	case NPPVjavascriptPushCallerBool:
+		D ("Unhandled variable NPPVjavascriptPushCallerBool");
+		err = NPERR_INVALID_PARAM;
+		break;
+	case NPPVpluginKeepLibraryInMemory:
+		D ("Unhandled variable NPPVpluginKeepLibraryInMemory");
+		err = NPERR_INVALID_PARAM;
+		break;
+	case NPPVpluginScriptableNPObject:
+		D ("Unhandled variable NPPVpluginScriptableNPObject");
+		err = NPERR_INVALID_PARAM;
+		break;
 	default:
 		D ("Unhandled variable");
 		err = NPERR_INVALID_PARAM;
@@ -279,6 +292,42 @@ NP_GetValue (void *future,
 	return totem_plugin_get_value (NULL, variable, value);
 }
 
+static gboolean
+totem_plugin_mimetype_is_disabled (const char *mimetype,
+				   GKeyFile *system,
+				   GKeyFile *user)
+{
+	GError *error = NULL;
+	gboolean retval;
+	char *key;
+
+	retval = FALSE;
+	key = g_strdup_printf ("%s.disabled", mimetype);
+
+	/* If the plugin is listed as enabled or disabled explicitely,
+	 * in the system-wide config file, then that's it */
+	if (system != NULL) {
+		retval = g_key_file_get_boolean (system, "Plugins", key, &error);
+		if (error == NULL) {
+			g_free (key);
+			return retval;
+		}
+		g_error_free (error);
+		error = NULL;
+	}
+
+	if (user != NULL) {
+		retval = g_key_file_get_boolean (user, "Plugins", key, &error);
+		if (error != NULL) {
+			g_error_free (error);
+			g_free (key);
+			return FALSE;
+		}
+	}
+
+	return retval;
+}
+
 char *
 NP_GetMIMEDescription (void)
 {
@@ -289,13 +338,41 @@ NP_GetMIMEDescription (void)
 
 	list = g_string_new (NULL);
 
+	/* Load the configuration files for the enabled plugins */
+	GKeyFile *system, *user;
+
+	system = g_key_file_new ();
+	user = g_key_file_new ();
+
+	if (g_key_file_load_from_file (system,
+				       SYSCONFDIR"/totem/browser-plugins.ini",
+				       G_KEY_FILE_NONE,
+				       NULL) == FALSE) {
+		g_key_file_free (system);
+		system = NULL;
+	}
+
+	char *user_ini_file;
+	user_ini_file = g_build_filename (g_get_user_config_dir (),
+					  "totem",
+					  "browser-plugins.ini",
+					  NULL);
+	if (g_key_file_load_from_file (user,
+				       user_ini_file,
+				       G_KEY_FILE_NONE,
+				       NULL) == FALSE) {
+		g_key_file_free (user);
+		user = NULL;
+	}
+	g_free (user_ini_file);
+
 	const totemPluginMimeEntry *mimetypes;
 	PRUint32 count;
 	totemScriptablePlugin::PluginMimeTypes (&mimetypes, &count);
 	for (PRUint32 i = 0; i < count; ++i) {
 		const char *desc;
 
-		if (mimetypes[i].ignore != FALSE)
+		if (totem_plugin_mimetype_is_disabled (mimetypes[i].mimetype, system, user))
 			continue;
 
 		desc = gnome_vfs_mime_get_description (mimetypes[i].mimetype);
@@ -315,6 +392,11 @@ NP_GetMIMEDescription (void)
 
 	mime_list = g_string_free (list, FALSE);
 
+	if (user != NULL)
+		g_key_file_free (user);
+	if (system != NULL)
+		g_key_file_free (system);
+
 	return mime_list;
 }
 
@@ -354,6 +436,18 @@ NP_Initialize (NPNetscapeFuncs * aMozillaFuncs,
 	if (plugin_funcs->size < sizeof (NPPluginFuncs))
 		return NPERR_INVALID_FUNCTABLE_ERROR;
 
+	/* we want to open libdbus-glib-1.so.2 in such a way
+	 * in such a way that it becomes permanentely resident */
+	void *handle;
+	handle = dlopen ("libdbus-glib-1.so.2", RTLD_NOW | RTLD_NODELETE);
+	if (!handle) {
+		fprintf (stderr, "%s\n", dlerror()); 
+		return NPERR_MODULE_LOAD_FAILED_ERROR;
+	}
+	/* RTLD_NODELETE allows us to close right away ... */
+	dlclose(handle);
+
+
 	/*
 	 * Copy all of the fields of the Mozilla function table into our
 	 * copy so we can call back into Mozilla later.  Note that we need
