@@ -22,7 +22,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -38,11 +38,34 @@
 #include "totem.h"
 #include "totem-private.h"
 #include "totem-preferences.h"
+#include "totem-interface.h"
 #include "video-utils.h"
 #include "totem-subtitle-encoding.h"
+#include "totem-plugin.h"
+#include "totem-plugins-engine.h"
 
 #include "debug.h"
 
+/* Callback functions for GtkBuilder */
+void checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+void checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+void checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+void tvout_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+void connection_combobox_changed (GtkComboBox *combobox, Totem *totem);
+void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
+void visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem);
+void brightness_changed (GtkRange *range, Totem *totem);
+void contrast_changed (GtkRange *range, Totem *totem);
+void saturation_changed (GtkRange *range, Totem *totem);
+void hue_changed (GtkRange *range, Totem *totem);
+void tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem);
+void audio_out_menu_changed (GtkComboBox *combobox, Totem *totem);
+void font_set_cb (GtkFontButton * fb, Totem * totem);
+void encoding_set_cb (GtkComboBox *cb, Totem *totem);
+void font_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
+void encoding_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
+
 static void
 totem_action_info (char *reason, Totem *totem)
 {
@@ -96,8 +119,8 @@ ask_show_visuals (Totem *totem)
 	return (answer == GTK_RESPONSE_YES ? TRUE : FALSE);
 }
 
-static void
-on_checkbutton1_toggled (GtkToggleButton *togglebutton, Totem *totem)
+void
+checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 {
 	gboolean value;
 
@@ -116,15 +139,15 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 	gconf_client_set_bool (totem->gc,
 			GCONF_PREFIX"/show_vfx", value, NULL);
 
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_label");
+	item = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tpw_visuals_type_label"));
 	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml,
-			"tpw_visuals_type_combobox");
+	item = GTK_WIDGET (gtk_builder_get_object (totem->xml,
+			"tpw_visuals_type_combobox"));
 	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_label");
+	item = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tpw_visuals_size_label"));
 	gtk_widget_set_sensitive (item, value);
-	item = glade_xml_get_widget (totem->xml,
-			"tpw_visuals_size_combobox");
+	item = GTK_WIDGET (gtk_builder_get_object (totem->xml,
+			"tpw_visuals_size_combobox"));
 	gtk_widget_set_sensitive (item, value);
 
 	if (warn == FALSE)
@@ -144,8 +167,8 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 	}
 }
 
-static void
-on_checkbutton2_toggled (GtkToggleButton *togglebutton, Totem *totem)
+void
+checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 {
 	gboolean value;
 
@@ -165,8 +188,32 @@ on_checkbutton2_toggled (GtkToggleButton *togglebutton, Totem *totem)
 	totem_prefs_set_show_visuals (totem, value, TRUE);
 }
 
-static void
-on_tvout_toggled (GtkToggleButton *togglebutton, Totem *totem)
+void
+checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
+{
+	gboolean value;
+
+	value = gtk_toggle_button_get_active (togglebutton);
+
+	gconf_client_set_bool (totem->gc,
+			       GCONF_PREFIX"/autoload_subtitles", value, NULL);
+	totem->autoload_subs = value;
+}
+
+void
+checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
+{
+	gboolean value;
+
+	value = gtk_toggle_button_get_active (togglebutton);
+
+	gconf_client_set_bool (totem->gc,
+			       GCONF_PREFIX"/lock_screensaver_on_audio", 
+			       value, NULL);
+}
+
+void
+tvout_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 {
 	TvOutType type;
 	gboolean value;
@@ -177,11 +224,8 @@ on_tvout_toggled (GtkToggleButton *togglebutton, Totem *totem)
 
 	type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (togglebutton),
 				"tvout_type"));
-	value = bacon_video_widget_set_tv_out
+	bacon_video_widget_set_tv_out
 		(BACON_VIDEO_WIDGET (totem->bvw), type);
-
-	if (value != FALSE)
-		totem_action_info (_("Switching on or off this type of TV-Out requires a restart to take effect."), totem);
 }
 
 static void
@@ -208,36 +252,72 @@ static void
 auto_resize_changed_cb (GConfClient *client, guint cnxn_id,
 		GConfEntry *entry, Totem *totem)
 {
-	GtkWidget *item;
+	GObject *item;
 
-	item = glade_xml_get_widget (totem->xml, "tpw_display_checkbutton");
-	g_signal_handlers_disconnect_by_func (G_OBJECT (item),
-			on_checkbutton1_toggled, totem);
+	item = gtk_builder_get_object (totem->xml, "tpw_display_checkbutton");
+	g_signal_handlers_disconnect_by_func (item,
+			checkbutton1_toggled_cb, totem);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
 			gconf_client_get_bool (totem->gc,
 				GCONF_PREFIX"/auto_resize", NULL));
 
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_checkbutton1_toggled), totem);
+	g_signal_connect (item, "toggled",
+			G_CALLBACK (checkbutton1_toggled_cb), totem);
 }
 
 static void
 show_vfx_changed_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, Totem *totem)
+		     GConfEntry *entry, Totem *totem)
 {
-	GtkWidget *item;
+	GObject *item;
 
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_checkbutton");
-	g_signal_handlers_disconnect_by_func (G_OBJECT (item),
-			on_checkbutton2_toggled, totem);
+	item = gtk_builder_get_object (totem->xml, "tpw_visuals_checkbutton");
+	g_signal_handlers_disconnect_by_func (item,
+			checkbutton2_toggled_cb, totem);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
 			gconf_client_get_bool (totem->gc,
 				GCONF_PREFIX"/show_vfx", NULL));
 
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_checkbutton2_toggled), totem);
+	g_signal_connect (item, "toggled",
+			G_CALLBACK (checkbutton2_toggled_cb), totem);
+}
+
+static void
+lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
+				      GConfEntry *entry, Totem *totem)
+{
+	GObject *item;
+
+	item = gtk_builder_get_object (totem->xml, "tpw_screensaver_checkbutton");
+	g_signal_handlers_disconnect_by_func (item,
+					      checkbutton4_toggled_cb, totem);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
+				      gconf_client_get_bool (totem->gc,
+							     GCONF_PREFIX"/lock_screensaver_on_audio", NULL));
+
+	g_signal_connect (item, "toggled",
+			  G_CALLBACK (checkbutton4_toggled_cb), totem);
+}
+
+static void
+autoload_subtitles_changed_cb (GConfClient *client, guint cnxn_id,
+			       GConfEntry *entry, Totem *totem)
+{
+	GObject *item;
+
+	item = gtk_builder_get_object (totem->xml, "tpw_auto_subtitles_checkbutton");
+	g_signal_handlers_disconnect_by_func (item,
+			checkbutton3_toggled_cb, totem);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
+			gconf_client_get_bool (totem->gc,
+				GCONF_PREFIX"/autoload_subtitles", NULL));
+
+	g_signal_connect (item, "toggled",
+			G_CALLBACK (checkbutton3_toggled_cb), totem);
 }
 
 static void
@@ -249,12 +329,12 @@ disable_save_to_disk_changed_cb (GConfClient *client, guint cnxn_id,
 
 	locked = gconf_client_get_bool (totem->gc,
 			"/desktop/gnome/lockdown/disable_save_to_disk", NULL);
-	item = glade_xml_get_widget (totem->xml,
-			"tmw_take_screenshot_menu_item");
+	item = GTK_WIDGET (gtk_builder_get_object (totem->xml,
+			"tmw_take_screenshot_menu_item"));
 	gtk_widget_set_sensitive (item, !locked);
 }
 
-static void
+void
 connection_combobox_changed (GtkComboBox *combobox, Totem *totem)
 {
 	int i;
@@ -264,7 +344,7 @@ connection_combobox_changed (GtkComboBox *combobox, Totem *totem)
 		(BACON_VIDEO_WIDGET (totem->bvw), i);
 }
 
-static void
+void
 visual_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	GList *list;
@@ -290,7 +370,7 @@ visual_menu_changed (GtkComboBox *combobox, Totem *totem)
 	g_free (old_name);
 }
 
-static void
+void
 visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	int i;
@@ -301,7 +381,7 @@ visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem)
 	bacon_video_widget_set_visuals_quality (totem->bvw, i);
 }
 
-static void
+void
 brightness_changed (GtkRange *range, Totem *totem)
 {
 	gdouble i;
@@ -311,7 +391,7 @@ brightness_changed (GtkRange *range, Totem *totem)
 			BVW_VIDEO_BRIGHTNESS, (int) i);
 }
 
-static void
+void
 contrast_changed (GtkRange *range, Totem *totem)
 {
 	gdouble i;
@@ -321,7 +401,7 @@ contrast_changed (GtkRange *range, Totem *totem)
 			BVW_VIDEO_CONTRAST, (int) i);
 }
 
-static void
+void
 saturation_changed (GtkRange *range, Totem *totem)
 {
 	gdouble i;
@@ -331,7 +411,7 @@ saturation_changed (GtkRange *range, Totem *totem)
 			BVW_VIDEO_SATURATION, (int) i);
 }
 
-static void
+void
 hue_changed (GtkRange *range, Totem *totem)
 {
 	gdouble i;
@@ -341,8 +421,8 @@ hue_changed (GtkRange *range, Totem *totem)
 			BVW_VIDEO_HUE, (int) i);
 }
 
-static void
-on_tpw_color_reset_clicked (GtkButton *button, Totem *totem)
+void
+tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem)
 {
 	guint i;
 	char *scales[] = {
@@ -353,13 +433,13 @@ on_tpw_color_reset_clicked (GtkButton *button, Totem *totem)
 	};
 
 	for (i = 0; i < G_N_ELEMENTS (scales); i++) {
-		GtkWidget *item;
-		item = glade_xml_get_widget (totem->xml, scales[i]);
-		gtk_range_set_value (GTK_RANGE (item), 65535/2);
+		GtkRange *item;
+		item = GTK_RANGE (gtk_builder_get_object (totem->xml, scales[i]));
+		gtk_range_set_value (item, 65535/2);
 	}
 }
 
-static void
+void
 audio_out_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	BaconVideoWidgetAudioOutType audio_out;
@@ -375,8 +455,8 @@ audio_out_menu_changed (GtkComboBox *combobox, Totem *totem)
 	}
 }
 
-static void
-on_font_set (GtkFontButton * fb, Totem * totem)
+void
+font_set_cb (GtkFontButton * fb, Totem * totem)
 {
 	const gchar *font;
 
@@ -385,8 +465,8 @@ on_font_set (GtkFontButton * fb, Totem * totem)
 				 font, NULL);
 }
 
-static void
-on_encoding_set (GtkComboBox *cb, Totem *totem)
+void
+encoding_set_cb (GtkComboBox *cb, Totem *totem)
 {
 	const gchar *encoding;
 
@@ -397,43 +477,44 @@ on_encoding_set (GtkComboBox *cb, Totem *totem)
 				encoding, NULL);
 }
 
-static void
+void
 font_changed_cb (GConfClient *client, guint cnxn_id,
 		 GConfEntry *entry, Totem *totem)
 {
 	const gchar *font;
-	GtkWidget *item;
+	GtkFontButton *item;
 
-	item = glade_xml_get_widget (totem->xml, "font_sel_button");
+	item = GTK_FONT_BUTTON (gtk_builder_get_object (totem->xml, "font_sel_button"));
 	font = gconf_value_get_string (entry->value);
-	gtk_font_button_set_font_name (GTK_FONT_BUTTON (item), font);
+	gtk_font_button_set_font_name (item, font);
 	bacon_video_widget_set_subtitle_font (totem->bvw, font);
 }
 
-static void
+void
 encoding_changed_cb (GConfClient *client, guint cnxn_id,
 		 GConfEntry *entry, Totem *totem)
 {
 	const gchar *encoding;
-	GtkWidget *item;
+	GtkComboBox *item;
 
-	item = glade_xml_get_widget (totem->xml, "subtitle_encoding_combo");
+	item = GTK_COMBO_BOX (gtk_builder_get_object (totem->xml, "subtitle_encoding_combo"));
 	encoding = gconf_value_get_string (entry->value);
-	totem_subtitle_encoding_set (GTK_COMBO_BOX(item), encoding);
+	totem_subtitle_encoding_set (item, encoding);
 	bacon_video_widget_set_subtitle_encoding (totem->bvw, encoding);
 }
 
 void
 totem_setup_preferences (Totem *totem)
 {
-	GtkWidget *item, *menu;
+	GtkWidget *menu;
 	GtkAction *action;
-	gboolean show_visuals, auto_resize, is_local, deinterlace;
+	gboolean show_visuals, auto_resize, is_local, deinterlace, lock_screensaver_on_audio;
 	int connection_speed, i;
 	char *visual, *font, *encoding;
 	GList *list, *l;
 	BaconVideoWidgetAudioOutType audio_out;
 	GConfValue *value;
+	GObject *item;
 
 	g_return_if_fail (totem->gc != NULL);
 
@@ -444,9 +525,6 @@ totem_setup_preferences (Totem *totem)
 	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/auto_resize",
 			(GConfClientNotifyFunc) auto_resize_changed_cb,
 			totem, NULL, NULL);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/show_vfx",
-			(GConfClientNotifyFunc) show_vfx_changed_cb,
-			totem, NULL, NULL);
 	gconf_client_add_dir (totem->gc, "/desktop/gnome/lockdown",
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_notify_add (totem->gc,
@@ -455,10 +533,10 @@ totem_setup_preferences (Totem *totem)
 			disable_save_to_disk_changed_cb,
 			totem, NULL, NULL);
 
-	/* Work-around glade dialogue not parenting properly for
+	/* Work-around builder dialogue not parenting properly for
 	 * On top windows */
-	item = glade_xml_get_widget (totem->xml, "tpw_notebook");
-	totem->prefs = gtk_dialog_new_with_buttons ("Preferences",
+	item = gtk_builder_get_object (totem->xml, "tpw_notebook");
+	totem->prefs = gtk_dialog_new_with_buttons (_("Preferences"),
 			GTK_WINDOW (totem->win),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE,
@@ -466,11 +544,20 @@ totem_setup_preferences (Totem *totem)
 			NULL);
 	gtk_dialog_set_has_separator (GTK_DIALOG (totem->prefs), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
-	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG(totem->prefs)->vbox), 2);
-	gtk_widget_reparent (item, GTK_DIALOG (totem->prefs)->vbox);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (totem->prefs)->vbox), 2);
+	gtk_widget_reparent (GTK_WIDGET (item), GTK_DIALOG (totem->prefs)->vbox);
 	gtk_widget_show_all (GTK_DIALOG (totem->prefs)->vbox);
-	item = glade_xml_get_widget (totem->xml, "totem_preferences_window");
-	gtk_widget_destroy (item);
+	item = gtk_builder_get_object (totem->xml, "totem_preferences_window");
+	gtk_widget_destroy (GTK_WIDGET (item));
+
+	/* Boldify some labels */
+	totem_interface_boldify_label (totem->xml, "tpw_network_label");
+	totem_interface_boldify_label (totem->xml, "tpw_tvout_label");
+	totem_interface_boldify_label (totem->xml, "tpw_text_subtitles_label");
+	totem_interface_boldify_label (totem->xml, "tpw_display_label");
+	totem_interface_boldify_label (totem->xml, "tpw_visuals_label");
+	totem_interface_boldify_label (totem->xml, "tpw_color_balance_label");
+	totem_interface_boldify_label (totem->xml, "tpw_audio_output_label");
 
 	g_signal_connect (G_OBJECT (totem->prefs), "response",
 			G_CALLBACK (gtk_widget_hide), NULL);
@@ -480,32 +567,54 @@ totem_setup_preferences (Totem *totem)
 	/* Auto-resize */
 	auto_resize = gconf_client_get_bool (totem->gc,
 			GCONF_PREFIX"/auto_resize", NULL);
-	item = glade_xml_get_widget (totem->xml, "tpw_display_checkbutton");
+	item = gtk_builder_get_object (totem->xml, "tpw_display_checkbutton");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), auto_resize);
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_checkbutton1_toggled), totem);
 	bacon_video_widget_set_auto_resize
 		(BACON_VIDEO_WIDGET (totem->bvw), auto_resize);
 
+	/* Screensaver audio locking */
+	lock_screensaver_on_audio = gconf_client_get_bool (totem->gc,
+							   GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
+	item = gtk_builder_get_object (totem->xml, "tpw_screensaver_checkbutton");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), lock_screensaver_on_audio);
+	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/lock_screensaver_on_audio",
+				 (GConfClientNotifyFunc) lock_screensaver_on_audio_changed_cb,
+				 totem, NULL, NULL);
+
 	/* Connection Speed */
 	connection_speed = bacon_video_widget_get_connection_speed (totem->bvw);
-	item = glade_xml_get_widget (totem->xml, "tpw_speed_combobox");
+	item = gtk_builder_get_object (totem->xml, "tpw_speed_combobox");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (item), connection_speed);
-	g_signal_connect (item, "changed",
-			G_CALLBACK (connection_combobox_changed), totem);
 
 	/* Enable visuals */
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_checkbutton");
+	item = gtk_builder_get_object (totem->xml, "tpw_visuals_checkbutton");
 	show_visuals = gconf_client_get_bool (totem->gc,
 			GCONF_PREFIX"/show_vfx", NULL);
 	if (is_local == FALSE && show_visuals != FALSE)
 		show_visuals = ask_show_visuals (totem);
 
+	g_signal_handlers_disconnect_by_func (item, checkbutton2_toggled_cb, totem);
 	gtk_toggle_button_set_active
 		(GTK_TOGGLE_BUTTON (item), show_visuals);
 	totem_prefs_set_show_visuals (totem, show_visuals, FALSE);
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_checkbutton2_toggled), totem);
+	g_signal_connect (item, "toggled", G_CALLBACK (checkbutton2_toggled_cb), totem);
+
+	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/show_vfx",
+			(GConfClientNotifyFunc) show_vfx_changed_cb,
+			totem, NULL, NULL);
+
+	/* Auto-load subtitles */
+	item = gtk_builder_get_object (totem->xml, "tpw_auto_subtitles_checkbutton");
+	totem->autoload_subs = gconf_client_get_bool (totem->gc,
+					      GCONF_PREFIX"/autoload_subtitles", NULL);
+
+	g_signal_handlers_disconnect_by_func (item, checkbutton3_toggled_cb, totem);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), totem->autoload_subs);
+	g_signal_connect (item, "toggled", G_CALLBACK (checkbutton3_toggled_cb), totem);
+
+	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/autoload_subtitles",
+				 (GConfClientNotifyFunc) autoload_subtitles_changed_cb,
+				 totem, NULL, NULL);
 
 	/* Visuals list */
 	list = bacon_video_widget_get_visuals_list (totem->bvw);
@@ -519,9 +628,7 @@ totem_setup_preferences (Totem *totem)
 		visual = g_strdup ("goom");
 	}
 
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_combobox");
-	g_signal_connect (G_OBJECT (item), "changed",
-			G_CALLBACK (visual_menu_changed), totem);
+	item = gtk_builder_get_object (totem->xml, "tpw_visuals_type_combobox");
 
 	i = 0;
 	for (l = list; l != NULL; l = l->next)
@@ -541,54 +648,37 @@ totem_setup_preferences (Totem *totem)
 	i = gconf_client_get_int (totem->gc,
 			GCONF_PREFIX"/visual_quality", NULL);
 	bacon_video_widget_set_visuals_quality (totem->bvw, i);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_combobox");
+	item = gtk_builder_get_object (totem->xml, "tpw_visuals_size_combobox");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (item), i);
-	g_signal_connect (G_OBJECT (item), "changed",
-			G_CALLBACK (visual_quality_menu_changed), totem);
 
 	/* Brightness */
-	item = glade_xml_get_widget (totem->xml, "tpw_bright_scale");
+	item = gtk_builder_get_object (totem->xml, "tpw_bright_scale");
 	i = bacon_video_widget_get_video_property (totem->bvw,
 			BVW_VIDEO_BRIGHTNESS);
 	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
-	g_signal_connect (G_OBJECT (item), "value-changed",
-			G_CALLBACK (brightness_changed), totem);
 
 	/* Contrast */
-	item = glade_xml_get_widget (totem->xml, "tpw_contrast_scale");
+	item = gtk_builder_get_object (totem->xml, "tpw_contrast_scale");
 	i = bacon_video_widget_get_video_property (totem->bvw,
 			BVW_VIDEO_CONTRAST);
 	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
-	g_signal_connect (G_OBJECT (item), "value-changed",
-			G_CALLBACK (contrast_changed), totem);
 
 	/* Saturation */
-	item = glade_xml_get_widget (totem->xml, "tpw_saturation_scale");
+	item = gtk_builder_get_object (totem->xml, "tpw_saturation_scale");
 	i = bacon_video_widget_get_video_property (totem->bvw,
 			BVW_VIDEO_SATURATION);
 	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
-	g_signal_connect (G_OBJECT (item), "value-changed",
-			G_CALLBACK (saturation_changed), totem);
 
 	/* Hue */
-	item = glade_xml_get_widget (totem->xml, "tpw_hue_scale");
+	item = gtk_builder_get_object (totem->xml, "tpw_hue_scale");
 	i = bacon_video_widget_get_video_property (totem->bvw,
 			BVW_VIDEO_HUE);
 	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
-	g_signal_connect (G_OBJECT (item), "value-changed",
-			G_CALLBACK (hue_changed), totem);
-
-	/* Reset colour balance */
-	item = glade_xml_get_widget (totem->xml, "tpw_color_reset");
-	g_signal_connect (G_OBJECT (item), "clicked",
-			G_CALLBACK (on_tpw_color_reset_clicked), totem);
 
 	/* Sound output type */
-	item = glade_xml_get_widget (totem->xml, "tpw_sound_output_combobox");
+	item = gtk_builder_get_object (totem->xml, "tpw_sound_output_combobox");
 	audio_out = bacon_video_widget_get_audio_out_type (totem->bvw);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (item), audio_out);
-	g_signal_connect (G_OBJECT (item), "changed",
-			G_CALLBACK (audio_out_menu_changed), totem);
 
 	/* This one is for the deinterlacing menu, not really our dialog
 	 * but we do it anyway */
@@ -603,13 +693,6 @@ totem_setup_preferences (Totem *totem)
 			(GConfClientNotifyFunc) deinterlace_changed_cb,
 			totem, NULL, NULL);
 
-	/* Always On Top */
-	action = gtk_action_group_get_action (totem->main_action_group,
-			"always-on-top");
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/window_on_top", NULL));
-
 	/* Save to disk Lockdown */
 	action = gtk_action_group_get_action (totem->main_action_group,
 			"take-screenshot");
@@ -619,8 +702,7 @@ totem_setup_preferences (Totem *totem)
 				NULL));
 
 	/* Subtitle font selection */
-	item = glade_xml_get_widget (totem->xml, "font_sel_button");
-	g_signal_connect (item, "font-set", G_CALLBACK (on_font_set), totem);
+	item = gtk_builder_get_object (totem->xml, "font_sel_button");
 	gtk_font_button_set_title (GTK_FONT_BUTTON (item),
 				   _("Select Subtitle Font"));
 	font = gconf_client_get_string (totem->gc,
@@ -635,9 +717,8 @@ totem_setup_preferences (Totem *totem)
 			totem, NULL, NULL);
 
 	/* Subtitle encoding selection */
-	item = glade_xml_get_widget (totem->xml, "subtitle_encoding_combo");
+	item = gtk_builder_get_object (totem->xml, "subtitle_encoding_combo");
 	totem_subtitle_encoding_init (GTK_COMBO_BOX (item));
-	g_signal_connect (item, "changed", G_CALLBACK (on_encoding_set), totem);
 	value = gconf_client_get_without_default (totem->gc,
 			GCONF_PREFIX"/subtitle_encoding", NULL);
 	/* Make sure the default is UTF-8 */
@@ -669,7 +750,7 @@ totem_setup_preferences (Totem *totem)
 void
 totem_preferences_tvout_setup (Totem *totem)
 {
-	GtkWidget *item;
+	GObject *item;
 	TvOutType type;
 	const char *name;
 
@@ -690,31 +771,25 @@ totem_preferences_tvout_setup (Totem *totem)
 		name = NULL;
 	}
 
-	item = glade_xml_get_widget (totem->xml, name);
+	item = gtk_builder_get_object (totem->xml, name);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), TRUE);
 
-	item = glade_xml_get_widget (totem->xml, "tpw_notvout_radio_button");
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_tvout_toggled), totem);
-	g_object_set_data (G_OBJECT (item), "tvout_type",
+	item = gtk_builder_get_object (totem->xml, "tpw_notvout_radio_button");
+	g_object_set_data (item, "tvout_type",
 			GINT_TO_POINTER (TV_OUT_NONE));
-	gtk_widget_set_sensitive(item, 
+	gtk_widget_set_sensitive (GTK_WIDGET (item), 
 			bacon_video_widget_fullscreen_mode_available (totem->bvw, TV_OUT_NONE));
 
-	item = glade_xml_get_widget (totem->xml, "tpw_nvtvpalmode_radio_button");
-        g_signal_connect (G_OBJECT (item), "toggled",
-                G_CALLBACK (on_tvout_toggled), totem);
-        g_object_set_data (G_OBJECT (item), "tvout_type",
+	item = gtk_builder_get_object (totem->xml, "tpw_nvtvpalmode_radio_button");
+        g_object_set_data (item, "tvout_type",
                 GINT_TO_POINTER (TV_OUT_NVTV_PAL));
-	gtk_widget_set_sensitive(item, 
+	gtk_widget_set_sensitive (GTK_WIDGET (item), 
 			bacon_video_widget_fullscreen_mode_available (totem->bvw, TV_OUT_NVTV_PAL));
 
-	item = glade_xml_get_widget (totem->xml, "tpw_nvtvntscmode_radio_button");
-	g_signal_connect (G_OBJECT (item), "toggled",
-			G_CALLBACK (on_tvout_toggled), totem);
-	g_object_set_data (G_OBJECT (item), "tvout_type",
+	item = gtk_builder_get_object (totem->xml, "tpw_nvtvntscmode_radio_button");
+	g_object_set_data (item, "tvout_type",
                 GINT_TO_POINTER (TV_OUT_NVTV_NTSC));
-	gtk_widget_set_sensitive(item, 
+	gtk_widget_set_sensitive (GTK_WIDGET (item), 
 			bacon_video_widget_fullscreen_mode_available (totem->bvw, TV_OUT_NVTV_NTSC));
 }
 
